/**
 * @file comp_ref.h
 * @date 2016-02-08
 *
 * NOTE:
 * This file is generated by DAVE. Any manual modification done to this file will be lost when the code is regenerated.
 *
 * @cond
 ***********************************************************************************************************************
 * COMP_REF v4.1.4 - APP is used to compare two analog signals.
 *                   Optionally BCCU or CCU4 can be used to generate a reference input to analog comparator.
 *
 * Copyright (c) 2016, Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following
 *   disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * To improve the quality of the software, users are encouraged to share modifications, enhancements or bug fixes
 * with Infineon Technologies AG (dave@infineon.com).
 ***********************************************************************************************************************
 *
 * Change History
 * --------------
 *
 * 2015-02-14:
 *     - Initial version for DAVEv4
 *
 * 2015-05-20:
 *     - Variable 'bccu_regs' type is changed to XMC_BCCU_t.
 *     - Variable 'passive_level' type is changed to XMC_BCCU_CH_ACTIVE_LEVEL_t.
 *     - Logic for LLD version check is added.
 *     - Modification in xmc_acmp.c lld is handled. XMC_ACMP_Init() API returns void.
 *     - Code is updated for addition of 'External reference' slection in APP.
 *
 * 2015-06-19:
 *     - COMP_REF_UpdateRefernceValue() API spell is corrected to COMP_REF_UpdateReferenceValue().
 *     - Variable 'reference_value' is changed to 'scaled_reference_value'.
 *     - LLD package version check is added.
 *
 * 2015-06-20:
 *     - Copyright information updated.
 *
 * 2015-11-13:
 *     -  To support ANALOG_IO APP,
 *     		> is_inp_enabled and is_inn_enabled are added to COMP_REF_CONFIG_t.
 *     		> analog_io_inp_ptr is added to COMP_REF_t
 *
 *2015-11-13:
 *     -  All initializations in COMP_REF_Init() are moved to local functions.<br>
 *
 * @endcond
 *
 */

#ifndef COMP_REF_H_
#define COMP_REF_H_

/***********************************************************************************************************************
 * HEADER FILES
 **********************************************************************************************************************/
#include "comp_ref_conf.h"

#include "../GLOBAL_ACMP/global_acmp.h"

#include <xmc_gpio.h>

#ifdef COMP_REF_CCU4_USED
#include "../GLOBAL_CCU4/global_ccu4.h"
#endif

#ifdef COMP_REF_BCCU_USED
#include "../GLOBAL_BCCU/global_bccu.h"
#endif

#ifdef COMP_REF_ERU_USED
#include <xmc_eru.h>
#endif

#ifdef ANALOG_IO_USED
#include "../ANALOG_IO/analog_io.h"
#endif


#if (!((XMC_LIB_MAJOR_VERSION == 2U) && \
       (XMC_LIB_MINOR_VERSION >= 0U) && \
       (XMC_LIB_PATCH_VERSION >= 0U)))
#error "COMP_REF requires XMC Peripheral Library v2.0.0 or higher"
#endif

/**********************************************************************************************************************
* MACROS
**********************************************************************************************************************/

/**********************************************************************************************************************
* ENUMS
**********************************************************************************************************************/
/**
 * @ingroup COMP_REF_enumerations
 * @{
 */

/**
 * @brief API return status
 */
typedef enum COMP_REF_STATUS
{
  COMP_REF_STATUS_SUCCESS              = 0U,   /**< API is successfully executed */
  COMP_REF_STATUS_FAILURE              = 1U,   /**< Failure in API execution */
  COMP_REF_STATUS_ALREADY_INITIALIZED  = 2U    /**< APP is already initialized */
} COMP_REF_STATUS_t;

/**
 * @brief Pulse generating module
 */
typedef enum COMP_REF_SOURCE
{
  COMP_REF_SOURCE_EXTERNAL             = 0U,   /**< External reference source is used */
  COMP_REF_SOURCE_CCU4                 = 1U,   /**< CCU4 is the reference source */
  COMP_REF_SOURCE_BCCU                 = 2U    /**< BCCU is the reference source */
} COMP_REF_SOURCE_t;

/**
 * @brief The type identifies App state.
 */
typedef enum COMP_REF_STATE
{
  COMP_REF_UNINITIALIZED               = 0U,   /**< Default state after power on reset */
  COMP_REF_INITIALIZED                 = 1U,   /**< APP is initialized as per selected parameters */
} COMP_REF_STATE_t;

/**
 * @}
 */

/**********************************************************************************************************************
* DATA STRUCTURES
**********************************************************************************************************************/
/**
  * @ingroup COMP_REF_datastructures
  * @{
  */

/**
 * Constant parameters of APP
 */
typedef struct COMP_REF_CONFIG
{
  const bool                                   eru_used;            /**< Selection of ERU */
  const bool                                   is_inp_enabled;      /**< check if ANALOG_IO pin is exposed.  */
  const bool                                   is_inn_enabled;      /**< check if ANALOG_IO pin is exposed.  */

  const COMP_REF_SOURCE_t                      ref_source;          /**< Selection of reference source - External reference or BCCU or CCU4 */
#if (defined COMP_REF_BCCU_USED) || (defined COMP_REF_CCU4_USED)
  const bool                                   ext_filter_enable;   /**< Selection of external filter */
  const uint16_t                               ref_voltage;         /**< Reference voltage */
  const uint16_t                               operating_voltage;   /**< Device operating voltage */
#endif

        GLOBAL_ACMP_t                   *const global_acmp_handle;  /**< Analog comparator global app handle pointer */
        XMC_ACMP_t                      *const comp_module_ptr;     /**< Analog comparator base address */
  const uint32_t                               comp_instance;       /**< Comparator instance used */
  const XMC_ACMP_CONFIG_t               *const comp_module_config;  /**< Pointer to Analog Comparator module configuration structure */
} COMP_REF_CONFIG_t;

/**
 * Constant parameters of CC4 slice configuration
 */
#ifdef COMP_REF_CCU4_USED
typedef struct COMP_REF_CCU4
{
        XMC_CCU4_MODULE_t               *const ccu4_module_ptr;     /**< Pointer to CCU4 module */
        XMC_CCU4_SLICE_t                *const cc4_slice_ptr;       /**< Pointer to CCU4_CC4 slice */
        GLOBAL_CCU4_t                   *const global_ccu4_handle;  /**< Pointer to GLOBAL_CCU4 APP */
        XMC_CCU4_SLICE_COMPARE_CONFIG_t *const cc4_compare_config;  /**< Pointer to xmc_ccu4 LLD compare configuration structure */
        uint32_t                               shadow_txfr_msk;     /**< Shadow transfer mask */
  const uint16_t                               period_value;        /**< Period value, defines PWM frequency */
  const uint16_t                               compare_value;       /**< Compare value, defines PWM's duty cycle */
  const uint8_t                                ccu4_kernel_number;  /**< CCU4 kernel number */
  const uint8_t                                cc4_slice_number;    /**< CC4 slice number */
} COMP_REF_CCU4_t;
#endif

/**
 * Constant parameters of BCCU configuration
 */
#ifdef COMP_REF_BCCU_USED
typedef struct COMP_REF_BCCU
{
        GLOBAL_BCCU_t                   *const global_bccu_handle;  /**< Pointer to GLOBAL_BCCU APP */

  /* BCCU Channel */
        XMC_BCCU_CH_CONFIG_t            *const bccu_ch_config;      /**< Pointer to xmc_bccu LLD channel configuration structure */
        XMC_BCCU_t                      *const bccu_regs;           /**< BCCU global register pointer */
        BCCU_CH_Type                    *const bccu_ch;             /**< BCCU channel specific register set */
  const uint32_t                               channel_number;      /**< Channel Number */
  const uint32_t                               linear_walk_time;    /**< Initial linear walk time */
  const uint32_t                               intensity;           /**< Channel initial intensity */
  const XMC_BCCU_CH_ACTIVE_LEVEL_t             passive_level;       /**< Channel Output Passive Level */
} COMP_REF_BCCU_t;
#endif

/**
 * Constant parameters of ERU configuration
 */
#ifdef COMP_REF_ERU_USED
typedef struct COMP_REF_ERU
{
        XMC_ERU_ETL_CONFIG_t            *const eru_etl_config;      /**< Pointer to ERU_ETL module */
        XMC_ERU_OGU_CONFIG_t            *const eru_ogu_config;      /**< Pointer to ERU_OGU module */
        XMC_ERU_t                       *const eru;                 /**< ERU module assigned(ERU0/ERU1) */
  const uint8_t                                ers_etl_channel;     /**< ERU channel assigned(0-3) */
  const uint8_t                                ogu_channel;         /**< ERU channel assigned(0-3) */
} COMP_REF_ERU_t;
#endif

/**
 * Constant parameters of reference source (BCCU/CCU) digital output configuration
 */
#ifdef COMP_REF_EXTERNAL_FILTER_USED
typedef struct COMP_REF_DIGITAL_OUT
{
        XMC_GPIO_PORT_t                 *const gpio_out_ptr;        /**< Pointer to GPIO port register */
  const uint8_t                                gpio_out_pin;        /**< Output pin */
  const XMC_GPIO_CONFIG_t               *const gpio_out_config;     /**< Output pin characteristics */
} COMP_REF_GPIO_t;
#endif

/**
 * Handler structure with pointers to dynamic and static parameters.
 */
typedef struct COMP_REF
{
        COMP_REF_CONFIG_t               *const config;              /**< Pointer to COMP_REF APP configuration structure */
        COMP_REF_STATE_t                       state;               /**< Identifies App state */

#ifdef COMP_REF_CCU4_USED
        COMP_REF_CCU4_t                 *const ccu4_config;         /**< Pointer to CCU4 configuration structure */
#endif

#ifdef COMP_REF_BCCU_USED
        COMP_REF_BCCU_t                 *const bccu_config;         /**< Pointer to BCCU configuration structure */
#endif

#ifdef COMP_REF_ERU_USED
        COMP_REF_ERU_t                  *const eru_config;               /**< Pointer to ERU configuration structure */
#endif

#ifdef COMP_REF_EXTERNAL_FILTER_USED
        COMP_REF_GPIO_t                 *const ref_output_pin_config;    /**< Pointer to GPIO configuration structure */
#endif

#ifdef COMP_REF_INTERNAL_FILTER_USED
        XMC_GPIO_PORT_t                 *      analog_io_inn_port;       /**< Pointer to Analog IO INn port handle */
        uint8_t                                pin;                      /**< Analog IO INn pin number */
#endif

#ifdef ANALOG_IO_USED
        ANALOG_IO_t                    const * const analog_io_inp_ptr;  /**< Pointer to Analog IO INP structure handle **/
        ANALOG_IO_t                    const * const analog_io_inn_ptr;  /**< Pointer to Analog IO INN structure handle **/
#endif

} COMP_REF_t;

/**
 * @}
 */

/***********************************************************************************************************************
 * API Prototypes
 **********************************************************************************************************************/
/* Support for C++ */
#ifdef __cplusplus
extern "C" {
#endif

/**
 * @ingroup COMP_REF_apidoc
 * @{
 */

/**
 * @brief Initializes COMP_REF APP parameters and lower level APP's
 * @param handle_ptr Pointer to an instance of COMP_REF APP
 * @return COMP_REF_STATUS_t
 * COMP_REF_STATUS_SUCCESS - for successful API execution
 * COMP_REF_STATUS_FAILURE - for failure in API execution
 *
 * \par<b>Description:</b><br>
 * The APP initializes Comparator module.
 *
 * Example Usage:
 * @code
 * #include <DAVE.h>
 * int main(void)
 * {
 *   DAVE_STATUS_t status;
 *
 *   status = DAVE_Init();  // COMP_REF_Init() is called from DAVE_Init()
 *
 *   while(1)
 *   {
 *   }
 *
 *   return 1;
 * }
 * @endcode <BR> </p>
 */
COMP_REF_STATUS_t COMP_REF_Init(COMP_REF_t *handle_ptr);

/**
 * @brief API updates the intensity value if BCCU is selected and updates the compare value if CCU4 is selected.
 * @param handle_ptr Pointer to an instance of COMP_REF APP
 * @param scaled_reference_value Required scaled voltage
 * @return COMP_REF_STATUS_t
 * COMP_REF_STATUS_SUCCESS - for successful API execution
 * COMP_REF_STATUS_FAILURE - for failure in API execution
 *
 * <b>Details of function</b><br>
 * If reference source is BCCU, the API calculates required intensity and programs the BCCU module,
 * else if the reference source is CCU4, the API calculates required duty cycle and programs the CCU4 module.
 *
 * <b>Note:</b><br>
 * Reference value needs to be up-scaled by 1023. Users can use the macro COMP_REF_SCALING_FACTOR for this.
 *
 * Example Usage:
 *
 * @code
 * #include <DAVE.h>
 *
 * int main(void)
 * {
 *   DAVE_STATUS_t init_status;
 *   COMP_REF_STATUS_t status;
 *
 *   init_status = DAVE_Init(); // COMP_REF_Init() is called from DAVE_Init()
 *
 *   if(init_status == DAVE_STATUS_FAILURE)
 *   {
 *     // Placeholder for error handler code. The while loop below can be replaced with an user error handler
 *     XMC_DEBUG(("DAVE Apps initialization failed with status %d\n", status));
 *     while(1U)
 *     {
 *     }
 *   }
 *
 *   //Required voltage is 1.585 volts. Therefore, scaled_reference_value = 1.585 * COMP_REF_SCALING_FACTOR
 *   status = COMP_REF_UpdateReferenceValue(&COMP_REF_0, (1.585 * COMP_REF_SCALING_FACTOR));
 *   if (status == COMP_REF_STATUS_SUCCESS)
 *   {
 *     // User code
 *   }
 *
 *   while(1) {
 *
 *   }
 *   return (0);
 * }
 * @endcode <BR> </p>
 */
COMP_REF_STATUS_t COMP_REF_UpdateReferenceValue(COMP_REF_t *handle_ptr, uint32_t scaled_reference_value);


/**
 * @brief Retrieves COMP_REF APP version
 * @return DAVE_APP_VERSION_t
 *
 * \par<b>Description:</b><br>
 * APP returns a version number (major, minor and patch number).
 * Applications may then audit such a version number to determine compatibility.
 *
 * Example Usage:
 *
 * @code
 * #include <DAVE.h>
 *
 * int main(void)
 * {
 *   DAVE_STATUS_t init_status;
 *   DAVE_APP_VERSION_t version;
 *
 *   init_status = DAVE_Init(); // COMP_REF_Init() is called from DAVE_Init()
 *
 *   version = COMP_REF_GetAppVersion();
 *   if (version.major != 4U)
 *   {
 *     // Probably, not the right version.
 *   }
 *
 *   while(1) {
 *
 *   }
 *   return (0);
 * }
 * @endcode <BR> </p>
 */
DAVE_APP_VERSION_t COMP_REF_GetAppVersion(void);
/**
 * @}
 */

/* Include APP extern declaration file */
#include "comp_ref_extern.h"

#ifdef __cplusplus
}
#endif

#endif /* COMP_REF_H_ */
