/**
 * @file dim_bccu.c
 * @date 2015-06-20
 *
 * NOTE:
 * This file is generated by DAVE. Any manual modification done to this file will be lost when the code is regenerated.
 *
 * @cond
 ***********************************************************************************************************************
 * DIM_BCCU v4.1.4 - DIM_BCCU APP configures the dimming engine registers of the Brightness and Color Control Unit (BCCU).
 *                   It also provides dynamic APIs to high level APPs such as DALI_CG and LED_LAMP.
 *
 * Copyright (c) 2015, Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * To improve the quality of the software, users are encouraged to share modifications, enhancements or bug fixes
 * with Infineon Technologies AG (dave@infineon.com).
 ***********************************************************************************************************************
 *
 * Change History
 * --------------
 *
 * 2015-02-16
 *     - Initial version.<br>
 *
 * 2015-05-07
 *     - New API's DIM_BCCU_SetDimCurveAndDither(),DIM_BCCU_IsDitherEnable() added.<br>
 *     - DIM_BCCU_GetDimCurve(),DIM_BCCU_GetDimDiv API's implementation is modified.<br>
 *     - DIM_BCCU_DitherDisable() , DIM_BCCU_DitherEnable() and DIM_BCCU_SetDimCurve() are removed.<br>
 *     - XMC_ASSERT is added in all API's.<br>
 *     - Comments are added for XMC_ASSERT().<br>
 *
 * @endcond
 *
 */

/***********************************************************************************************************************
 * HEADER FILES
 **********************************************************************************************************************/
#include "dim_bccu.h"

/***********************************************************************************************************************
 * MACROS
 **********************************************************************************************************************/

/***********************************************************************************************************************
 * LOCAL DATA
 **********************************************************************************************************************/

/***********************************************************************************************************************
 * LOCAL ROUTINES
 **********************************************************************************************************************/

 /**********************************************************************************************************************
 * API IMPLEMENTATION
 **********************************************************************************************************************/

/*
 * @brief API to retrieve the version of the DIM_BCCU
 *
 * @return DAVE_APP_VERSION_t Structure containing major version, minor version
 *         and patch version.
 */
DAVE_APP_VERSION_t DIM_BCCU_GetAppVersion(void)
{
  DAVE_APP_VERSION_t version;

  version.major = (uint8_t)DIM_BCCU_MAJOR_VERSION;
  version.minor = (uint8_t)DIM_BCCU_MINOR_VERSION;
  version.patch = (uint8_t)DIM_BCCU_PATCH_VERSION;

  return (version);
}

/**
 * @brief   This function Initializes a DIM_BCCU APP instances based on
 *          user configuration.
 */
DIM_BCCU_STATUS_t DIM_BCCU_Init(DIM_BCCU_t *handle)
{
  DIM_BCCU_STATUS_t status;

  /* Checks input parameters when XMC_ASSERT is enabled. Useful for Debugging */
  XMC_ASSERT("DIM_BCCU APP handle function pointer uninitialized", (((handle != NULL) &&
      		(handle->bccu_de_regs != NULL)) &&((handle->config != NULL) && (handle->global_bccu_handleptr != NULL) &&
      	    (handle->enable_at_start <= 1) && (handle->dim_engine_num <= 2) && (handle->dim_lvl <= 4095U))));

  /* Checking for initialization state of the instance */
  /* GLOBAL_BCCU APP Initialization for XMC1000 devices */
  status = (DIM_BCCU_STATUS_t)GLOBAL_BCCU_Init(handle->global_bccu_handleptr);
  if (status != DIM_BCCU_STATUS_FAILURE)
  {
    /* DIM_BCCU APP Initialization for XMC1000 devices */
    XMC_BCCU_DIM_Init(handle->bccu_de_regs, handle->config);
    /* Initial Dimming Level configuration */
    XMC_BCCU_DIM_SetTargetDimmingLevel(handle->bccu_de_regs, handle->dim_lvl);
    if (DIM_BCCU_ENABLE_AT_INIT_TRUE == handle->enable_at_start)
    {
      /* Dimming Engine Enable at Initialization for XMC1000 devices */
      XMC_BCCU_EnableDimmingEngine(handle->global_bccu_handleptr->bccuregs, (uint32_t)handle->dim_engine_num);

      /* Start Dimming Engine at Initialization for XMC1000 devices */
      XMC_BCCU_StartDimming(handle->global_bccu_handleptr->bccuregs, (uint32_t)handle->dim_engine_num);
    }
    /* Return status after initialization */
    status = DIM_BCCU_STATUS_SUCCESS;
   }
  return (status);
}
/**
 * @brief	This function is used to enable dimming Engine.
 *
 * @param handle Instance object handle
 * @return None.
 */
void DIM_BCCU_Enable(DIM_BCCU_t *handle)
{
  XMC_ASSERT("DIM_BCCU_Enable: handler null pointer", handle != NULL);
  XMC_BCCU_EnableDimmingEngine(handle->global_bccu_handleptr->bccuregs, (uint32_t)handle->dim_engine_num);
}
/**
 * @brief	 This function is used to disable dimming Engine.
 *
 * @param handle Instance object handle
 * @return None.
 */
void DIM_BCCU_Disable(DIM_BCCU_t * handle)
{
  XMC_ASSERT("DIM_BCCU_Disable: handler null pointer", handle != NULL);
  XMC_BCCU_DisableDimmingEngine(handle->global_bccu_handleptr->bccuregs, (uint32_t)handle->dim_engine_num);
}
/**
 * @brief	 This function is used to start dimming Engine.
 *
 * @param handle Instance object handle
 * @return None
 */
void DIM_BCCU_StartDimming(DIM_BCCU_t *handle)
{
  XMC_ASSERT("DIM_BCCU_StartDimming: handler null pointer", handle != NULL);
  XMC_BCCU_StartDimming(handle->global_bccu_handleptr->bccuregs, (uint32_t)handle->dim_engine_num);
}
/**
 * @brief	 This function is used to abort dimming Engine.
 *
 * @param handle Instance object handle
 * @return None.
 *
 */
void DIM_BCCU_AbortDimming(DIM_BCCU_t *handle)
{
  XMC_ASSERT("DIM_BCCU_AbortDimming: handler null pointer", handle != NULL);
  XMC_BCCU_AbortDimming(handle->global_bccu_handleptr->bccuregs, (uint32_t)handle->dim_engine_num);
}
/**
 * @brief	 This function is used to set target dimming level.
 *
 * @param handle Instance object handle
 * @param dimlevel target dimming level
 * @return None.<BR>
 */
void DIM_BCCU_SetDimLvl(DIM_BCCU_t *handle, uint32_t dimlevel)
{
  XMC_ASSERT("DIM_BCCU_SetDimLvl: handler null pointer", handle != NULL);
  XMC_BCCU_DIM_SetTargetDimmingLevel(handle->bccu_de_regs, dimlevel);
}
/**
 * @brief	 This function is used to get target dimming level.
 *
 * @param handle Instance object handle
 * @return uint32_t target dimming level.<BR>
 */
uint32_t DIM_BCCU_GetDimLvl(DIM_BCCU_t *handle)
{
  XMC_ASSERT("DIM_BCCU_GetDimLvl: handler null pointer", handle != NULL);
  return (XMC_BCCU_DIM_ReadDimmingLevel(handle->bccu_de_regs));
}
/**
 * @brief	 This function is used to get dimming curve.
 *
 * @param handle Instance object handle
 * @return XMC_BCCU_DIM_CURVE_t dimming curve.<BR>
 */
XMC_BCCU_DIM_CURVE_t DIM_BCCU_GetDimCurve(DIM_BCCU_t *handle)
{
  XMC_ASSERT("DIM_BCCU_GetDimCurve: handler null pointer", handle != NULL);
  return(XMC_BCCU_DIM_GetDimCurve(handle->bccu_de_regs));
}

/**
 * @brief	This function is used to verify dimming completion status.
 *
 * @param handle Instance object handle
 * @return uint32_t status of dimming completion.<BR>
 *
 */
uint32_t DIM_BCCU_FadeCompletionStatus(DIM_BCCU_t * handle)
{
  XMC_ASSERT("DIM_BCCU_FadeCompletionStatus: handler null pointer", handle != NULL);
  return (XMC_BCCU_IsDimmingFinished((handle->global_bccu_handleptr->bccuregs), (uint32_t)handle->dim_engine_num));
}
/**
 * @brief	This function is used to wait untill dimming process completion.
 *
 * @param handle Instance object handle
 * @return None.<BR>
 */
void DIM_BCCU_AwaitFadeCompletion(DIM_BCCU_t *handle)
{
  XMC_ASSERT("DIM_BCCU_AwaitFadeCompletion: handler null pointer", handle != NULL);
  /* Poll until the fading has completed */
  while (1U == (XMC_BCCU_IsDimmingFinished((handle->global_bccu_handleptr->bccuregs),
               (uint32_t)handle->dim_engine_num)))
  {

  }
}
/**
 * @brief	This function is used to set dimming prescaler value.
 *
 * @param handle Instance object handle
 * @param dimdiv dimming prescaler value
 * @return None.<BR>
 */
void DIM_BCCU_SetDimDiv(DIM_BCCU_t *handle, uint32_t dimdiv)
{
  XMC_ASSERT("DIM_BCCU_SetDimDiv: handler null pointer", handle != NULL);
  XMC_BCCU_DIM_SetDimDivider(handle->bccu_de_regs, dimdiv);
}
/**
 * @brief	This function is used to get dimming prescaler value.
 *
 * @param handle Instance object handle
 * @return uint32_t.<BR>
 *
 */
uint32_t DIM_BCCU_GetDimDiv(DIM_BCCU_t *handle)
{
  XMC_ASSERT("DIM_BCCU_GetDimDiv: handler null pointer", handle != NULL);
  return (XMC_BCCU_DIM_ReadDimDivider(handle->bccu_de_regs));
}

/**
 * @brief	This function is used to get dither status.
 *
 * @param handle Instance object handle
 * @return uint32_t.<BR>
 *
 */
uint32_t DIM_BCCU_IsDitherEnable(DIM_BCCU_t *handle)
{
  XMC_ASSERT("DIM_BCCU_IsDitherEnable: handler null pointer", handle != NULL);
  return (XMC_BCCU_IsDitherEnable(handle->bccu_de_regs));
}

/**
 * @brief	This function is used to set dither and curve simultaneously.
 *
 * @param handle Instance object handle
 * @return None.<BR>
 *
 */
void DIM_BCCU_SetDimCurveAndDither(DIM_BCCU_t *handle, uint32_t dither, XMC_BCCU_DIM_CURVE_t curve)
{
  XMC_ASSERT("DIM_BCCU_SetDimCurveAndDither: handler null pointer", handle != NULL);
  XMC_BCCU_DIM_ConfigDimCurve(handle->bccu_de_regs, dither, curve);
}

