/**
 * @file global_acmp.h
 * @date 2015-07-31
 *
 * NOTE:
 * This file is generated by DAVE. Any manual modification done to this file will be lost when the code is regenerated.
 *
 * @cond
 ***********************************************************************************************************************
 * GLOBAL_ACMP v4.0.6 - Initializes analog comparator power mode of operation.
 *
 * Copyright (c) 2015, Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * To improve the quality of the software, users are encouraged to share modifications, enhancements or bug fixes
 * with Infineon Technologies AG (dave@infineon.com).
 ***********************************************************************************************************************
 *
 * Change History
 * --------------
 *
 * 2015-06-04:
 *     - Initial version 4.0.2<br>
 *
 *
 * @endcond
 *
 */
/***********************************************************************************************************************
 * HEADER FILES
 **********************************************************************************************************************/
#ifndef GLOBAL_ACMP_H
#define GLOBAL_ACMP_H

#include <xmc_acmp.h>
#include <DAVE_Common.h>
#include "global_acmp_conf.h"

#if (!((XMC_LIB_MAJOR_VERSION == 2U) && \
       (XMC_LIB_MINOR_VERSION >= 0U) && \
       (XMC_LIB_PATCH_VERSION >= 0U)))
#error "GLOBAL_ACMP requires XMC Peripheral Library v2.0.0 or higher"
#endif
/***********************************************************************************************************************
 * MACROS
 **********************************************************************************************************************/
typedef void (*GLOBAL_ACMP_PowerModeSelect)(void);

/**********************************************************************************************************************
* ENUMS
**********************************************************************************************************************/
/**
 * @ingroup GLOBAL_ACMP_enumerations
 * @{
 */
typedef enum GLOBAL_ACMP_STATUS
{
  GLOBAL_ACMP_STATUS_SUCCESS = 0U, /**< Status success */
  GLOBAL_ACMP_STATUS_FAILURE       /**< Status failure */
} GLOBAL_ACMP_STATUS_t;
/**
* @}
*/

/**
 * @ingroup GLOBAL_ACMP_datastructures
 * @{
 */
/**********************************************************************************************************************
* DATA STRUCTURES
**********************************************************************************************************************/
/**
 * This saves the context of the GLOBAL_ACMP APP.
 */
typedef struct GLOBAL_ACMP
{
  GLOBAL_ACMP_PowerModeSelect power_mode_select;  /**< comparator low power mode selection*/
  bool  initialized;                              /**< Holds the initialization status */
} GLOBAL_ACMP_t;

/**
 * @}
 */
/**********************************************************************************************************************
 * API Prototypes
 *********************************************************************************************************************/
#ifdef __cplusplus
extern "C" {
#endif
/**
 * @ingroup GLOBAL_ACMP_apidoc
 * @{
 */

/**
 * @brief Get GLOBAL_ACMP APP version
 * @return DAVE_APP_VERSION_t APP version information (major, minor and patch number)
 * <BR>
 * \par<b>Description:</b><br>
 * The function can be used to check application software compatibility with a
 * specific version of the APP.
 *
 * Example Usage:
 * @code
 * #include <DAVE.h>
 * int main(void)
 * {
 *   DAVE_STATUS_t status;
 *   DAVE_APP_VERSION_t app_version;
 *
 *   status = DAVE_Init();	// GLOBAL_ACMP_Init() is called from DAVE_Init()
 *
 *   if (status == DAVE_STATUS_SUCCESS)
 *   {
 *     app_version = GLOBAL_ACMP_GetAppVersion();
 *   }
 *
 *   if (app_version.major != 4U)
 *   {
 *     // Probably, not the right version.
 *   }
 *
 *   while(1U)
 *   {
 *   }
 *   return 1;
 * }
 * @endcode<BR>
 */
DAVE_APP_VERSION_t GLOBAL_ACMP_GetAppVersion(void);

/**
 * @brief Configures the analog comparators to operate in low power mode depending upon the configuration provided.
 *
 * @param constant pointer to the GLOBAL_ACMP APP handle structure.
 * @return @ref GLOBAL_ACMP_STATUS_t\n  GLOBAL_ACMP_STATUS_SUCCESS : if initialization is successful\n
 *                                      GLOBAL_ACMP_STATUS_FAILURE : if initialization is failed\n
 * <BR>
 * \par<b>Description:</b><br>
 * It programs the LPWR bit field of ANACMP0 register to set the low power mode of operation.
 *
 * Example Usage:
 * @code
 * #include <DAVE.h>
 * int main(void)
 * {
 *   DAVE_STATUS_t status;
 *
 *   status = DAVE_Init();      // GLOBAL_ACMP_Init() is called from DAVE_Init()
 *
 *   if(status == DAVE_STATUS_SUCCESS)
 *   {
 *     XMC_DEBUG("DAVE Apps initialization success\n");
 *   }
 *   else
 *   {
 *     // Placeholder for error handler code. The while loop below can be replaced with an user error handler
 *     XMC_DEBUG(("DAVE Apps initialization failed with status %d\n", status));
 *     while(1U)
 *     {
 *     }
 *   }
 *   // Placeholder for user application code. The while loop below can be replaced with user application code.
 *   while(1U)
 *   {
 *   }
 *
 * }
 * @endcode<BR>
 */
GLOBAL_ACMP_STATUS_t GLOBAL_ACMP_Init(GLOBAL_ACMP_t *const handle);


/**
 * @}
 */
#ifdef __cplusplus
}
#endif

#include "global_acmp_extern.h"

#endif /*GLOBAL_ACMP_H*/
