/**
 * @file pdm_bccu.c
 * @date 2015-06-20
 *
 * NOTE:
 * This file is generated by DAVE. Any manual modification done to this file will be lost when the code is regenerated.
 *
 * @cond
 ***********************************************************************************************************************
 * PDM_BCCU v4.1.6 - PDM_BCCU APP configures the Channel registers of the Brightness and Color Control Unit (BCCU).
 *
 * Copyright (c) 2015, Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * To improve the quality of the software, users are encouraged to share modifications, enhancements or bug fixes
 * with Infineon Technologies AG (dave@infineon.com).
 ***********************************************************************************************************************
 *
 * Change History
 * --------------
 *
 * 2015-02-16
 *     - Initial version.<br>
 *
 * 2015-05-07
 *     - PDM_BCCU_SelDimEngine() removed.<br>
 *     - XMC_ASSERT is added in all API's.<br>
 *
 *
 * @endcond
 *
 */

/***********************************************************************************************************************
 * HEADER FILES
 **********************************************************************************************************************/
#include "pdm_bccu.h"

/***********************************************************************************************************************
 * MACROS
 **********************************************************************************************************************/

/***********************************************************************************************************************
 * LOCAL DATA
 **********************************************************************************************************************/

/***********************************************************************************************************************
 * LOCAL ROUTINES
 **********************************************************************************************************************/

 /**********************************************************************************************************************
 * API IMPLEMENTATION
 **********************************************************************************************************************/

/*
 * @brief API to retrieve the version of the PDM_BCCU
 *
 * @return DAVE_APP_VERSION_t Structure containing major version, minor version
 *         and patch version.
 */
DAVE_APP_VERSION_t PDM_BCCU_GetAppVersion(void)
{
  DAVE_APP_VERSION_t version;

  version.major = (uint8_t)PDM_BCCU_MAJOR_VERSION;
  version.minor = (uint8_t)PDM_BCCU_MINOR_VERSION;
  version.patch = (uint8_t)PDM_BCCU_PATCH_VERSION;

  return (version);
}

/**
 * @brief This function Initializes a  PDM_BCCU APP instances based on user
 *          configuration.
 */

PDM_BCCU_STATUS_t PDM_BCCU_Init(PDM_BCCU_t * handle)
{
  PDM_BCCU_STATUS_t status;

  /* Checks input parameters when XMC_ASSERT is enabled. Useful for Debugging */
  XMC_ASSERT("PDM_BCCU APP handle function pointer uninitialized", (((handle != NULL) &&
  			(handle->bccu_regs != NULL)) && ((handle->config != NULL) && (handle->gpio_config != NULL) &&
            (handle->gpio_port != NULL) && (handle->bccu_ch != NULL) && (handle->global_bccu_handleptr != NULL) &&
           (handle->channel_enable_at_init <= 1) && (handle->channel_no <= 8U) && (handle->linear_walk_time <= 1023U) &&
            (handle->intensity <= 4095U) && (handle->output_level <= 1) && (handle->trigger_line <= 1))));

  /* Checking for initialization state of the instance */

  /* GLOBAL_BCCU APP Initialization for XMC1000 devices */
  status = (PDM_BCCU_STATUS_t)GLOBAL_BCCU_Init(handle->global_bccu_handleptr);
  if (status != PDM_BCCU_STATUS_FAILURE)
  {
    if (true == handle->output_pin_enable)
    {
      /* Hardware initialization based on UI */
      XMC_GPIO_Init(handle->gpio_port, handle->gpio_pin, handle->gpio_config);
    }
    XMC_BCCU_SetOutputPassiveLevel(handle->bccu_regs, handle->channel_no,
    		                      (XMC_BCCU_CH_ACTIVE_LEVEL_t)handle->output_level);
    if (true == handle->trap_enable)
    {
      XMC_BCCU_EnableTrap (handle->bccu_regs, handle->channel_no);
    }
    if ((bool)true == handle->trigger_en)
    {
      XMC_BCCU_CH_ConfigTrigger(handle->bccu_ch,
                               (XMC_BCCU_CH_TRIG_EDGE_t)handle->config->trig_edge,handle->config->force_trig_en);
      XMC_BCCU_EnableChannelTrigger (handle->bccu_regs, handle->channel_no,
    		                        (XMC_BCCU_CH_TRIGOUT_t)handle->trigger_line);
    }
    XMC_BCCU_CH_Init(handle->bccu_ch, handle->config);

    if (PDM_BCCU_ENABLE_AT_INIT_TRUE == handle->channel_enable_at_init)
    {
      /* To set the linear walker prescaler factor of a BCCU channel */
      XMC_BCCU_CH_SetLinearWalkPrescaler(handle->bccu_ch, handle->linear_walk_time);

      /* Channel Enable at Initialization for XMC1000 devices */
      XMC_BCCU_EnableChannel(handle->bccu_regs, handle->channel_no);

      /* To set the set the channel target intensity */
      XMC_BCCU_CH_SetTargetIntensity(handle->bccu_ch, handle->intensity);

      /* To Start Linear Walk of channel */
      XMC_BCCU_StartLinearWalk(handle->bccu_regs,handle->channel_no);
    }
    /* Return status after updation */
    status = PDM_BCCU_STATUS_SUCCESS;
  }
  return (status);
}

/**
* @brief API to Enable the Channel.
*/
void PDM_BCCU_EnableChannel(PDM_BCCU_t *handle)
{
  XMC_ASSERT("PDM_BCCU_EnableChannel: handler null pointer", handle != NULL);
  XMC_BCCU_EnableChannel(handle->bccu_regs, handle->channel_no);
}
/**
* @brief API to Disable the Channel.
*/
void PDM_BCCU_DisableChannel(PDM_BCCU_t *handle)
{
  XMC_ASSERT("PDM_BCCU_DisableChannel: handler null pointer", handle != NULL);
  XMC_BCCU_DisableChannel(handle->bccu_regs, handle->channel_no);
}

/**
* @brief API to Enable the Gate.
*/
void PDM_BCCU_GateEnable(PDM_BCCU_t *handle)
{
  XMC_ASSERT("PDM_BCCU_GateEnable: handler null pointer", handle != NULL);
  XMC_BCCU_CH_EnableGating(handle->bccu_ch);
}

/**
* @brief  API to Disable the Gate.
*/
void PDM_BCCU_GateDisable(PDM_BCCU_t *handle)
{
  XMC_ASSERT("PDM_BCCU_GateDisable: handler null pointer", handle != NULL);
  XMC_BCCU_CH_DisableGating(handle->bccu_ch);
}
/**
* @brief API to Set Channel Intensity.
*/
void PDM_BCCU_SetIntensity(PDM_BCCU_t *handle, uint32_t intensity)
{
  XMC_ASSERT("PDM_BCCU_SetIntensity: handler null pointer", handle != NULL);
  XMC_BCCU_CH_SetTargetIntensity(handle->bccu_ch, intensity);
}

/**
* @brief API to Set Linear Walk.
*/
void PDM_BCCU_SetLinearWalk(PDM_BCCU_t *handle, uint32_t prescalar)
{
  XMC_ASSERT("PDM_BCCU_SetLinearWalk: handler null pointer", handle != NULL);
  XMC_BCCU_CH_SetLinearWalkPrescaler(handle->bccu_ch, prescalar);
}
/**
* @brief  API to Start Linear Walk.
*/
void PDM_BCCU_StartLinearWalk(PDM_BCCU_t *handle)
{
  XMC_ASSERT("PDM_BCCU_StartLinearWalk: handler null pointer", handle != NULL);
  XMC_BCCU_StartLinearWalk(handle->bccu_regs,handle->channel_no);
}

/**
* @brief  API to Abort Linear Walk.
*/
void PDM_BCCU_AbortLinearWalk(PDM_BCCU_t *handle)
{
  XMC_ASSERT("PDM_BCCU_AbortLinearWalk: handler null pointer", handle != NULL);
  XMC_BCCU_AbortLinearWalk(handle->bccu_regs, handle->channel_no);
}

/**
* @brief  To get Channel Linear Walk status.
*/
uint32_t PDM_BCCU_LinearWalkStatus(PDM_BCCU_t *handle)
{
  XMC_ASSERT("PDM_BCCU_LinearWalkStatus: handler null pointer", handle != NULL);
  return (XMC_BCCU_IsLinearWalkComplete(handle->bccu_regs,handle->channel_no));
}

/**
* @brief  Wait indefinitely till linear walk is over.
*/
void PDM_BCCU_AwaitEndOfLinearWalk(PDM_BCCU_t *handle)
{
  XMC_ASSERT("PDM_BCCU_AwaitEndOfLinearWalk: handler null pointer", handle != NULL);
  while (1U == (XMC_BCCU_IsLinearWalkComplete(handle->bccu_regs, handle->channel_no)))
  {

  }
}
