/**
 * @file comp_ref.c
 * @date 2016-02-08
 *
 * NOTE:
 * This file is generated by DAVE. Any manual modification done to this file will be lost when the code is regenerated.
 *
 * @cond
 ***********************************************************************************************************************
 * COMP_REF v4.1.4 - APP is used to compare two analog signals.
 *                   Optionally BCCU or CCU4 can be used to generate a reference input to analog comparator.
 *
 * Copyright (c) 2016, Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following
 *   disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * To improve the quality of the software, users are encouraged to share modifications, enhancements or bug fixes
 * with Infineon Technologies AG (dave@infineon.com).
 ***********************************************************************************************************************
 *
 * Change History
 * --------------
 *
 * 2015-05-14:
 *     - Initial version for DAVEv4
 *
 * 2015-05-20:
 *     -  Modification in xmc_acmp.c lld is handled.
 *     -  In COMP_REF_lACMP_Init() API XMC_ACMP_EnableComparator() API is called.
 *     -  COMP_REF_UpdateReferenceValue() API is optimized.
 *     -  Divisions and multiplications are replaced by shifting operations.
 *     -  Created private API's COMP_REF_lUpdateBccuReferenceValue(), COMP_REF_lUpdateCcuReferenceValue().
 *     -  COMP_REF_UpdateRefernceValue() API spell is corrected to COMP_REF_UpdateReferenceValue().
 *     -  Variable 'reference_value' is changed to 'scaled_reference_value'.
 *
 * 2015-06-20:
 *     - Copyright information updated.
 *
 * 2015-07-06:
 *     - Intensity and compare value calculation is corrected.
 *
 * 2015-11-13:
 *     -  To support ANALOG_IO APP,
 *     		> ANALOG_IO_Init() is conditionally called in COMP_REF_Init().
 *     		> This code block is conditionally compiled using ANALOG_IO_USED Macro.
 *
 *2015-11-13:
 *     -  All initializations in COMP_REF_Init() are moved to local functions.<br>
 *
 * @endcond
 *
 */

/***********************************************************************************************************************
 * HEADER FILES
 **********************************************************************************************************************/
#include "comp_ref.h"

/***********************************************************************************************************************
 * MACROS
 **********************************************************************************************************************/

/***********************************************************************************************************************
 * LOCAL DATA
 **********************************************************************************************************************/

/***********************************************************************************************************************
 * LOCAL ROUTINES
 **********************************************************************************************************************/

COMP_REF_STATUS_t COMP_REF_lAcmpInit(COMP_REF_CONFIG_t *handle_ptr);

#ifdef COMP_REF_ERU_USED
COMP_REF_STATUS_t COMP_REF_lEruInit(COMP_REF_t *handle_ptr);
#endif

#ifdef COMP_REF_CCU4_USED
COMP_REF_STATUS_t COMP_REF_lCcuInit(COMP_REF_CCU4_t *handle_ptr);
COMP_REF_STATUS_t COMP_REF_lUpdateCcuReferenceValue(COMP_REF_t *handle_ptr, uint32_t scaled_reference_value);
#endif

#ifdef COMP_REF_BCCU_USED
COMP_REF_STATUS_t COMP_REF_lBccuInit(COMP_REF_BCCU_t *handle_ptr);
COMP_REF_STATUS_t COMP_REF_lUpdateBccuReferenceValue(COMP_REF_t * handle_ptr, uint32_t scaled_reference_value);
#endif

#if ( ((defined COMP_REF_BCCU_USED) || (defined COMP_REF_CCU4_USED))   && (defined COMP_REF_EXTERNAL_FILTER_USED))
COMP_REF_STATUS_t COMP_REF_lGPIO_Init(COMP_REF_t *handle_ptr);
#endif

#if ((defined COMP_REF_BCCU_USED) || (defined COMP_REF_CCU4_USED))
COMP_REF_STATUS_t COMP_REF_lReferenceSrc_Init(COMP_REF_t *handle_ptr);
#endif

#if (defined COMP_REF_INTERNAL_FILTER_USED)
COMP_REF_STATUS_t COMP_REF_lInternalFilter_Enable(COMP_REF_t *handle_ptr);
#endif

#ifdef ANALOG_IO_USED
COMP_REF_STATUS_t COMP_REF_lAnalog_IO_Init(COMP_REF_t *handle_ptr);
#endif



/**********************************************************************************************************************
* API IMPLEMENTATION
***********************************************************************************************************************/

/* API to retrieve driver version info */
DAVE_APP_VERSION_t COMP_REF_GetAppVersion(void)
{
  DAVE_APP_VERSION_t version;
  
  version.major = COMP_REF_MAJOR_VERSION;
  version.minor = COMP_REF_MINOR_VERSION;
  version.patch = COMP_REF_PATCH_VERSION;

  return version;
}

/* Initialize COMP_REF APP parameters and lower level APP's */
COMP_REF_STATUS_t COMP_REF_Init(COMP_REF_t *handle_ptr)
{
  COMP_REF_STATUS_t status = COMP_REF_STATUS_FAILURE;

  XMC_ASSERT("COMP_REF_Init: handle_ptr is NULL", (handle_ptr != NULL));

  if (COMP_REF_UNINITIALIZED == handle_ptr->state)
  {
    status = COMP_REF_lAcmpInit(handle_ptr->config);

#ifdef COMP_REF_ERU_USED
    if (COMP_REF_STATUS_SUCCESS == status)
    {
      COMP_REF_lEruInit(handle_ptr);
    }
#endif

#if ( ((defined COMP_REF_BCCU_USED) || (defined COMP_REF_CCU4_USED))   && (defined COMP_REF_EXTERNAL_FILTER_USED))
    if (COMP_REF_STATUS_SUCCESS == status)
    {
      status = COMP_REF_lGPIO_Init(handle_ptr);
    }
#endif

#if ((defined COMP_REF_BCCU_USED) || (defined COMP_REF_CCU4_USED))

    if (COMP_REF_STATUS_SUCCESS == status)
    {
      status = COMP_REF_lReferenceSrc_Init(handle_ptr);
    }


#endif


#ifdef ANALOG_IO_USED

    if (COMP_REF_STATUS_SUCCESS == status)
    {
      status = COMP_REF_lAnalog_IO_Init(handle_ptr);
    }
#endif


#if (defined COMP_REF_INTERNAL_FILTER_USED)

    if (COMP_REF_STATUS_SUCCESS == status)
    {
      status = COMP_REF_lInternalFilter_Enable(handle_ptr);
    }


#endif


    if (COMP_REF_STATUS_SUCCESS == status)
    {
      handle_ptr->state = COMP_REF_INITIALIZED;
    }
    else
    {
      handle_ptr->state = COMP_REF_UNINITIALIZED;
    }
  }
  else
  {
    status = COMP_REF_STATUS_ALREADY_INITIALIZED;
  }

  return (status);
}

#if (defined COMP_REF_BCCU_USED) || (defined COMP_REF_CCU4_USED)
/*
 *  If reference source is BCCU, the API calculates required intensity and programs the BCCU module,
 * else if the reference source is CCU4, the API calculates required duty cycle and programs the CCU4 module
 *
 * Note: Reference value needs to be up-scaled by 1023. Users can use the macro COMP_REF_SCALING_FACTOR for this.
 * */
COMP_REF_STATUS_t COMP_REF_UpdateReferenceValue(COMP_REF_t *handle_ptr, uint32_t scaled_reference_value)
{
  COMP_REF_STATUS_t status = COMP_REF_STATUS_FAILURE;

#ifdef COMP_REF_BCCU_USED
  if (COMP_REF_SOURCE_BCCU == handle_ptr->config->ref_source)
  {
    status = COMP_REF_lUpdateBccuReferenceValue(handle_ptr, scaled_reference_value);
  }
#endif

#ifdef COMP_REF_CCU4_USED
  if (COMP_REF_SOURCE_CCU4 == handle_ptr->config->ref_source)
  {
    status = COMP_REF_lUpdateCcuReferenceValue(handle_ptr, scaled_reference_value);
  }
#endif

  return (status);
}
#endif

#ifdef COMP_REF_BCCU_USED

COMP_REF_STATUS_t COMP_REF_lUpdateBccuReferenceValue(COMP_REF_t * handle_ptr, uint32_t scaled_reference_value)
{
  uint32_t intensity;

  COMP_REF_STATUS_t status = COMP_REF_STATUS_FAILURE;

  if (scaled_reference_value <= handle_ptr->config->operating_voltage)
  {
    intensity = (scaled_reference_value * COMP_REF_BCCU_CONST) / handle_ptr->config->operating_voltage;

    /* Sets channel target intensity */
    XMC_BCCU_CH_SetTargetIntensity(handle_ptr->bccu_config->bccu_ch, intensity);

    /* Start Linear Walk of channel */
    XMC_BCCU_StartLinearWalk(handle_ptr->bccu_config->bccu_regs, handle_ptr->bccu_config->channel_number);

    status = COMP_REF_STATUS_SUCCESS;
  }
  else
  {
    status = COMP_REF_STATUS_FAILURE; /* reference value is more than the operating_voltage */
  }

  return (status);
}
#endif

#ifdef COMP_REF_CCU4_USED

COMP_REF_STATUS_t COMP_REF_lUpdateCcuReferenceValue(COMP_REF_t *handle_ptr, uint32_t scaled_reference_value)
{
  uint32_t compare_value;

  COMP_REF_STATUS_t status = COMP_REF_STATUS_FAILURE;

  if (scaled_reference_value <= handle_ptr->config->operating_voltage)
  {
    compare_value =  (handle_ptr->config->operating_voltage - scaled_reference_value);
    compare_value = (handle_ptr->ccu4_config->period_value * compare_value) + compare_value;
    compare_value =  (compare_value / handle_ptr->config->operating_voltage);

    /* Set timer compare match value for channel */
    XMC_CCU4_SLICE_SetTimerCompareMatch(handle_ptr->ccu4_config->cc4_slice_ptr, (uint16_t) compare_value);

    /* Transfer value from shadow timer registers to actual timer registers */
    XMC_CCU4_EnableShadowTransfer(handle_ptr->ccu4_config->ccu4_module_ptr, handle_ptr->ccu4_config->shadow_txfr_msk);

    status = COMP_REF_STATUS_SUCCESS;
  }
  else
  {
    status = COMP_REF_STATUS_FAILURE; /* reference value is more than the operating_voltage */
  }

  return (status);
}
#endif

/* Initializes analog comparator module */
COMP_REF_STATUS_t COMP_REF_lAcmpInit(COMP_REF_CONFIG_t *handle_ptr)
{
  COMP_REF_STATUS_t status = COMP_REF_STATUS_FAILURE;

  /* Initialize GLOBAL_ACMP APP */
  status = (COMP_REF_STATUS_t) GLOBAL_ACMP_Init(handle_ptr->global_acmp_handle);

  /* Initialize analog comparator slice */
  if (COMP_REF_STATUS_SUCCESS == status)
  {
    /* Configure ACMP module with the specified values associated with the handle */
    XMC_ACMP_Init(handle_ptr->comp_module_ptr, handle_ptr->comp_instance, handle_ptr->comp_module_config);

    /* Enable the comparator during initialization */
    XMC_ACMP_EnableComparator(handle_ptr->comp_module_ptr, handle_ptr->comp_instance);
  }

  return (status);
}

#ifdef COMP_REF_ERU_USED
/* Initializes ERU module */
COMP_REF_STATUS_t COMP_REF_lEruInit(COMP_REF_t *handle_ptr)
{
  COMP_REF_STATUS_t status = COMP_REF_STATUS_FAILURE;
  COMP_REF_ERU_t *eru_config = handle_ptr->eru_config;

  if (true == handle_ptr->config->eru_used)
  {
    /* ERU ETL initialization */
    XMC_ERU_ETL_Init(eru_config->eru  , eru_config->ers_etl_channel, eru_config->eru_etl_config);

    /* ERU OGU initialization */
    XMC_ERU_OGU_Init(eru_config->eru, eru_config->ogu_channel, eru_config->eru_ogu_config);

    status = COMP_REF_STATUS_SUCCESS;
  }
  else
  {/* ERU is not selected. Do Nothing */
    status = COMP_REF_STATUS_SUCCESS;
  }
  return status;
}
#endif

#ifdef COMP_REF_CCU4_USED
/* Initializes CCU4 module */
COMP_REF_STATUS_t COMP_REF_lCcuInit(COMP_REF_CCU4_t *handle_ptr)
{
  COMP_REF_STATUS_t status = COMP_REF_STATUS_FAILURE;

  /* Initialize GLOBAL_CCU4 APP */
  status = (COMP_REF_STATUS_t) GLOBAL_CCU4_Init(handle_ptr->global_ccu4_handle);

  /* Initialize CCU4x_CC4y slice */
  if (COMP_REF_STATUS_SUCCESS == status)
  {
    /* Configure CCU4x_CC4y slice as timer */
    XMC_CCU4_SLICE_CompareInit(handle_ptr->cc4_slice_ptr, handle_ptr->cc4_compare_config);

    /* Set period match value of the timer  */
    XMC_CCU4_SLICE_SetTimerPeriodMatch(handle_ptr->cc4_slice_ptr, handle_ptr->period_value);

    /* Set timer compare match value for channel */
    XMC_CCU4_SLICE_SetTimerCompareMatch(handle_ptr->cc4_slice_ptr, (uint16_t) handle_ptr->compare_value);

    /* Transfer value from shadow timer registers to actual timer registers */
    XMC_CCU4_EnableShadowTransfer(handle_ptr->ccu4_module_ptr, handle_ptr->shadow_txfr_msk);

    /* Clear IDLE mode for the slice; Start timer */
    XMC_CCU4_EnableClock(handle_ptr->ccu4_module_ptr, handle_ptr->cc4_slice_number);

    /* Start the timer */
    XMC_CCU4_SLICE_StartTimer(handle_ptr->cc4_slice_ptr);
  }

  return (status);
}
#endif

#ifdef COMP_REF_BCCU_USED
/* Initializes BCCU module */
COMP_REF_STATUS_t COMP_REF_lBccuInit(COMP_REF_BCCU_t *handle_ptr)
{
  COMP_REF_STATUS_t status = COMP_REF_STATUS_FAILURE;

  /* Initialize GLOBAL_CCU4 APP */
  status = (COMP_REF_STATUS_t) GLOBAL_BCCU_Init(handle_ptr->global_bccu_handle);

  /* Initialize CCU4x_CC4y slice */
  if (COMP_REF_STATUS_SUCCESS == status)
  {
    XMC_BCCU_SetOutputPassiveLevel(handle_ptr->bccu_regs, handle_ptr->channel_number, handle_ptr->passive_level);
    XMC_BCCU_CH_Init(handle_ptr->bccu_ch, handle_ptr->bccu_ch_config);
    XMC_BCCU_CH_SetLinearWalkPrescaler(handle_ptr->bccu_ch, handle_ptr->linear_walk_time);

    /* Channel Enable at Initialization for XMC1000 devices */
    XMC_BCCU_EnableChannel(handle_ptr->bccu_regs, handle_ptr->channel_number);

    /* Sets channel target intensity */
    XMC_BCCU_CH_SetTargetIntensity(handle_ptr->bccu_ch, handle_ptr->intensity);

    /* Starts Linear Walk of channel */
    XMC_BCCU_StartLinearWalk(handle_ptr->bccu_regs, handle_ptr->channel_number);
  }
  return (status);
}
#endif



#ifdef ANALOG_IO_USED

COMP_REF_STATUS_t COMP_REF_lAnalog_IO_Init(COMP_REF_t *handle_ptr)
{
  COMP_REF_STATUS_t status = COMP_REF_STATUS_SUCCESS;

  if (true == handle_ptr->config->is_inn_enabled)
  {
    if (ANALOG_IO_STATUS_OK != ANALOG_IO_Init(handle_ptr->analog_io_inn_ptr))
    {
      status = COMP_REF_STATUS_FAILURE;
    }
  }

  if (true == handle_ptr->config->is_inp_enabled)
  {
    if (ANALOG_IO_STATUS_OK != ANALOG_IO_Init(handle_ptr->analog_io_inp_ptr))
    {
      status = COMP_REF_STATUS_FAILURE;
    }
  }
  return status;
}
#endif


#if (defined COMP_REF_INTERNAL_FILTER_USED)

COMP_REF_STATUS_t COMP_REF_lInternalFilter_Enable(COMP_REF_t *handle_ptr)
{
  COMP_REF_STATUS_t status = COMP_REF_STATUS_SUCCESS;

  if ((false == handle_ptr->config->ext_filter_enable)
         && (COMP_REF_SOURCE_EXTERNAL != handle_ptr->config->ref_source))
  {/* Internal Filter used */

#ifdef ANALOG_IO_USED
    if (true == handle_ptr->config->is_inn_enabled)
    {
      handle_ptr->analog_io_inn_port = handle_ptr->analog_io_inn_ptr->port;
      handle_ptr->pin = handle_ptr->analog_io_inn_ptr->pin;
    }
#endif
    if (COMP_REF_SOURCE_BCCU == handle_ptr->config->ref_source)
    {
      XMC_GPIO_SetHardwareControl(handle_ptr->analog_io_inn_port, handle_ptr->pin, XMC_GPIO_HWCTRL_PERIPHERAL1);
    }
    if (COMP_REF_SOURCE_CCU4 == handle_ptr->config->ref_source)
    {
      XMC_GPIO_SetHardwareControl(handle_ptr->analog_io_inn_port, handle_ptr->pin, XMC_GPIO_HWCTRL_PERIPHERAL2);
    }
    XMC_GPIO_EnableDigitalInput(handle_ptr->analog_io_inn_port, handle_ptr->pin);
  }
  else
  {/* this is a corner case. External Filter is used here */
    status = COMP_REF_STATUS_SUCCESS; /* do nothing */
  }
  return status;
}
#endif


#if ((defined COMP_REF_BCCU_USED) || (defined COMP_REF_CCU4_USED))

COMP_REF_STATUS_t COMP_REF_lReferenceSrc_Init(COMP_REF_t *handle_ptr)
{
  COMP_REF_STATUS_t status = COMP_REF_STATUS_SUCCESS;

#ifdef COMP_REF_CCU4_USED
  if (COMP_REF_SOURCE_CCU4 == handle_ptr->config->ref_source)
  {
    if (COMP_REF_STATUS_SUCCESS != COMP_REF_lCcuInit(handle_ptr->ccu4_config))
    {
      status = COMP_REF_STATUS_FAILURE;
    }
  }
#endif

#ifdef COMP_REF_BCCU_USED
  if (COMP_REF_SOURCE_BCCU == handle_ptr->config->ref_source)
  {
    if (COMP_REF_STATUS_SUCCESS != COMP_REF_lBccuInit(handle_ptr->bccu_config))
    {
      status = COMP_REF_STATUS_FAILURE;
    }
  }
#endif

  return status;
}

#endif


#if ( ((defined COMP_REF_BCCU_USED) || (defined COMP_REF_CCU4_USED))   && (defined COMP_REF_EXTERNAL_FILTER_USED))

COMP_REF_STATUS_t COMP_REF_lGPIO_Init(COMP_REF_t *handle_ptr)
{
  COMP_REF_STATUS_t status= COMP_REF_STATUS_FAILURE;

  if (true == handle_ptr->config->ext_filter_enable)
  {
    XMC_GPIO_Init(handle_ptr->ref_output_pin_config->gpio_out_ptr, handle_ptr->ref_output_pin_config->gpio_out_pin,
      handle_ptr->ref_output_pin_config->gpio_out_config);
    status = COMP_REF_STATUS_SUCCESS;
  }
  else
  {
    status = COMP_REF_STATUS_SUCCESS;
  }

  return status;
}


#endif
