/*******************************************************************************
 Copyright (c) 2016, Infineon Technologies AG                                 **
 All rights reserved.                                                         **
                                                                              **
 Redistribution and use in source and binary forms, with or without           **
 modification,are permitted provided that the following conditions are met:   **
                                                                              **
 *Redistributions of source code must retain the above copyright notice,      **
 this list of conditions and the following disclaimer.                        **
 *Redistributions in binary form must reproduce the above copyright notice,   **
 this list of conditions and the following disclaimer in the documentation    **
 and/or other materials provided with the distribution.                       **
 *Neither the name of the copyright holders nor the names of its contributors **
 may be used to endorse or promote products derived from this software without**
 specific prior written permission.                                           **
                                                                              **
 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"  **
 AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE    **
 IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE   **
 ARE  DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE   **
 LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR         **
 CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF         **
 SUBSTITUTE GOODS OR  SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS    **
 INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN      **
 CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)       **
 ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE   **
 POSSIBILITY OF SUCH DAMAGE.                                                  **
                                                                              **
 To improve the quality of the software, users are encouraged to share        **
 modifications, enhancements or bug fixes with Infineon Technologies AG       **
 dave@infineon.com).                                                          **
                                                                              **
********************************************************************************
**                                                                            **
**                                                                            **
** PLATFORM : Infineon XMC1000 Series                                         **
**                                                                            **
** AUTHOR : Application Engineering Team                                      **
**                                                                            **
** version 1.0.0  Initial version                                             **
**                                                                            **
** MODIFICATION DATE : January, 29, 2016                                      **
**                                                                            **
*******************************************************************************/

/****************************************************************
* HEADER FILES
***************************************************************/
#include <DAVE.h>                 //Declarations from DAVE Code Generation (includes SFR declaration)
#include "expdim.h"

/****************************************************************
* MACROS
***************************************************************/
#define ONE_MS 1000U

/* Macros for Automatic Current Ripple Tuning */
#define R_SHUNT                            5U      /* (1/0.2) Ohm */
#define DELAY_DROP                         140U    /* fixed propagation delay when turning off MOSFETs */
#define IREF_CALCULATION_CONSTANT          136533U /* IREF_SCALE_ADJUSTMENT/R_SHUNT/VREF_GAIN*(2^IREF_CALCULATION_SCALING) */
#define IREF_CALCULATION_SCALING           15U
#define IAVG_CALCULATION_CONSTANT          124830U /* 100/105*(2^IAVG_CALCULATION_SCALING) */
#define IAVG_CALCULATION_SCALING           17U
#define IOVERSHOOT_CALCULATION_CONSTANT    1U      /* DELAY_RISE/L*IOVERSHOOT_SCALE_ADJUSTMENT */
#define OFFTIME_CALCULATION_CONSTANT       300U    /* 2*L*OFFTIME_SCALE_ADJUSTMENT */
#define TIMER_COMPARE_CALCULATION_CONSTANT 16777U  /* (1/TIMER_RESOLUTION)*(2^TIMER_COMPARE_CALCULATION_SCALING) */
#define TIMER_COMPARE_CALCULATION_SCALING  18U

/****************************************************************
* GLOBAL VARIABLES
***************************************************************/
uint16_t PotResult;        /* Potmeter ADC conversion result (to dim LEDs) */
uint32_t average_poti = 0; /* Average PotResult */
uint32_t status;           /* Declaration of return variable for DAVE APIs */
int8_t   *ptr_chipid; /* pointer to flash location for unique chip ID */

/* Variables for Automatic Current Ripple Tuning */
uint32_t reference_current;   /* reference current */
uint32_t voltage_drop_leds;   /* voltage drop through LEDs */
uint32_t offtime;             /* CCU8 fixed off-time */
uint8_t  tune_ripple = 0;     /* 0: ripple is ok, 1: ripple needs to be tuned */
uint32_t peak_current;        /* calculated peak current (IPEAK) */
uint32_t overshoot_current;   /* calculated overshoot current (IOVERSHOOT) */
uint32_t target_avgcurr;      /* the target average current (IAVR,target) */
uint32_t ripple_current;      /* current ripple (IRIPPLE,target) */
uint16_t timer_compare;       /* CCU8 compare register value */
uint16_t wait = 0U;           /* delay counter to let lightnow stabilise */
uint16_t VINResult;           /* input voltage (VIN) */
uint16_t LEDSense;            /* inductor voltage (VL) */
uint16_t reference_voltage;   /* reference voltage (VREF) */
uint16_t input_voltage_saved = 0U; /* previously saved input voltage */
uint16_t inductor_volt_saved = 0U; /* previously saved inductor voltage */
uint16_t stable_vin = 0U;
uint16_t stable_vl = 0U;
uint8_t  first_tuning = 1U;

/****************************************************************
* FUNCTION DECLARATION
***************************************************************/
void mytimerinterrupt(void); /* 1ms periodic interrupt handler declaration */
void current_ripple_tuning(void);

/**

 * @brief main() - Application entry point
 *
 * <b>Details of function</b><br>
 * This routine is the application entry point. It is invoked by the device startup code. It is responsible for
 * invoking the APP initialization dispatcher routine - DAVE_Init() and hosting the place-holder for user application
 * code.
 */

int main(void)
{
  uint32_t mytimer_id;

  status = DAVE_Init();           /* Initialization of DAVE APPs  */

  if(status == DAVE_STATUS_FAILURE)
  {
    /* Placeholder for error handler code. The while loop below can be replaced with an user error handler. */
    XMC_DEBUG("DAVE APPs initialization failed\n");

    while(1U)
    {

    }
  }

  /* Generate load event to start measurement for reference voltage */
  ADC_MEASUREMENT_ADV_SoftwareTrigger(&ADC_MEASUREMENT_ADV_1);

  /* Set lamp to 25% dim level for ripple tuning */
  PDM_DIMMED_LED_LAMP_0_config.dim_level = 1024U;
  PDM_DIMMED_LED_LAMP_SetDimLevelExponential(&PDM_DIMMED_LED_LAMP_0);

  /* create timer for periodic interrupt */
  mytimer_id = SYSTIMER_CreateTimer(ONE_MS, SYSTIMER_MODE_PERIODIC, (SYSTIMER_CALLBACK_t)mytimerinterrupt, NULL);
  /* start timer */
  status = SYSTIMER_StartTimer(mytimer_id);

  /* Placeholder for user application code. The while loop below can be replaced with user application code. */
  while(1U)
  {

  }
}

/* adc queue interrupt service routine */
void adc_queue_callback(void)
{
  uint16_t input_voltage_change;
  uint16_t inductor_volt_change;

  if(tune_ripple == 0U)
  {
    VINResult = ADC_MEASUREMENT_ADV_GetResult(&ADC_MEASUREMENT_ADV_0_Channel_A);
    LEDSense = ADC_MEASUREMENT_ADV_GetResult(&ADC_MEASUREMENT_ADV_0_Channel_B);
    wait = 0U;

    /**** Check if VIN has changed and tune ripple if needed ****/
    if(VINResult > input_voltage_saved) input_voltage_change = VINResult - input_voltage_saved;
    else input_voltage_change = input_voltage_saved - VINResult;
    if(input_voltage_change > 150U)
    {
      if(++stable_vin == 1000U)
      {
        input_voltage_saved = VINResult;
        tune_ripple = 1U;
        stable_vin = 0U;
      }
    }
    else
    {
      stable_vin = 0U;
    }

    /*** Check if LEDSense has changed and tune ripple if needed ****/
    if(LEDSense > inductor_volt_saved) inductor_volt_change = LEDSense - inductor_volt_saved;
    else inductor_volt_change = inductor_volt_saved - LEDSense;
    if(inductor_volt_change > 80U)
    {
      if(++stable_vl == 1000U)
      {
        inductor_volt_saved = LEDSense;
    	tune_ripple = 1U;
    	stable_vl = 0U;
      }
    }
    else
    {
      stable_vl = 0U;
    }
  }
}

/* adc scan interrupt service routine */
void adc_scan_callback(void)
{
  reference_voltage = ADC_MEASUREMENT_ADV_GetResult(&ADC_MEASUREMENT_ADV_1_Channel_A);

  /* Calculate reference current */
  /* reference_current=VRef/ADC_GAIN/RRef */
  reference_current = (reference_voltage * IREF_CALCULATION_CONSTANT) >> IREF_CALCULATION_SCALING;
  /* Calculate target average current */
  target_avgcurr = (reference_current * IAVG_CALCULATION_CONSTANT) >> IAVG_CALCULATION_SCALING;
}

/* timer interrupt - triggers every 1ms */
void mytimerinterrupt(void)
{
  /* use Potmeter reading to control LED brightness */
  uint32_t dimlevel;
  uint32_t linlevel;

  if(first_tuning == 0U)
  {
  /* read ADC result */
  PotResult = ADC_MEASUREMENT_GetResult(&ADC_MEASUREMENT_Channel_A_handle);

  /* calculate target dimming level */
  average_poti = PotResult + average_poti - (average_poti>>8); /* filter the result because the signal is a bit noisy */
  linlevel = average_poti>>8;
  dimlevel = expdim[linlevel>>4]; /* use exponential targets to make dimming more fun */
  if(dimlevel > 4095U)
  {
	dimlevel = 4095U;
  }
  else if(dimlevel < 0U)
  {
	dimlevel = 0U;
  }
  PDM_DIMMED_LED_LAMP_0_config.dim_level = dimlevel;
  PDM_DIMMED_LED_LAMP_SetDimLevelExponential(&PDM_DIMMED_LED_LAMP_0); /* go to target level immediately */
  }

  if(tune_ripple == 1U)
  {
    current_ripple_tuning();
  }
}

void current_ripple_tuning(void)
{
  /* Calculate overshoot current */
  overshoot_current = LEDSense * IOVERSHOOT_CALCULATION_CONSTANT;
  /* Calculate peak current */
  peak_current = reference_current + overshoot_current;
  /* Calculate current ripple */
  ripple_current = peak_current - target_avgcurr;
  /* Calculate voltage drop through LEDs */
  voltage_drop_leds = (VINResult - LEDSense);
  /* Calculate the desired offtime (minus propagation delay) */
  offtime = ((OFFTIME_CALCULATION_CONSTANT * ripple_current) / voltage_drop_leds);
  if(offtime > DELAY_DROP) offtime = offtime  - DELAY_DROP;
  else offtime = 0U;
  /* Convert offtime to CCU8 register compare value equivalent */
  timer_compare = (offtime * TIMER_COMPARE_CALCULATION_CONSTANT)>>TIMER_COMPARE_CALCULATION_SCALING;
  /* Configure CCU8 and restart timer */
  PWM_CCU8_Stop(&PWM_CCU8_0);
  XMC_CCU8_SLICE_SetTimerCompareMatch(PWM_CCU8_0.ccu8_slice_ptr,XMC_CCU8_SLICE_COMPARE_CHANNEL_1,timer_compare);
  XMC_CCU8_EnableShadowTransfer(PWM_CCU8_0.ccu8_module_ptr,PWM_CCU8_0.shadow_txfr_msk);
  PWM_CCU8_Start(&PWM_CCU8_0);

  /* ripple adjustment completed */
  tune_ripple = 0U;
  first_tuning = 0U;
}
